==> centreon-web-23.04.29.tar.gz: centreon-web-23.04.29/src/Core/Contact/Infrastructure/Api/FindContactTemplates/FindContactTemplatesPresenter.php <==
<?php

/*
 * Copyright 2005 - 2022 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Contact\Infrastructure\Api\FindContactTemplates;

use Core\Application\Common\UseCase\AbstractPresenter;
use Core\Contact\Application\UseCase\FindContactTemplates\{
    FindContactTemplatesPresenterInterface,
    FindContactTemplatesResponse
};
use Core\Infrastructure\Common\Presenter\PresenterFormatterInterface;
use Centreon\Domain\RequestParameters\Interfaces\RequestParametersInterface;

class FindContactTemplatesPresenter extends AbstractPresenter implements FindContactTemplatesPresenterInterface
{
    /**
     * @param RequestParametersInterface $requestParameters
     * @param PresenterFormatterInterface $presenterFormatter
     */
    public function __construct(
        private RequestParametersInterface $requestParameters,
        protected PresenterFormatterInterface $presenterFormatter,
    ) {
    }

    /**
     * @param FindContactTemplatesResponse $presentedData
     * @return void
     */
    public function present(mixed $presentedData): void
    {
        parent::present([
            'result' => $presentedData->contactTemplates,
            'meta' => $this->requestParameters->toArray()
        ]);
    }
}

==> centreon-web-23.10.24.tar.gz: centreon-web-23.10.24/src/Core/Contact/Infrastructure/Api/FindContactTemplates/FindContactTemplatesPresenter.php <==
<?php

/*
 * Copyright 2005 - 2023 Centreon (https://www.centreon.com/)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * For more information : contact@centreon.com
 *
 */

declare(strict_types=1);

namespace Core\Contact\Infrastructure\Api\FindContactTemplates;

use Centreon\Domain\RequestParameters\Interfaces\RequestParametersInterface;
use Core\Application\Common\UseCase\AbstractPresenter;
use Core\Contact\Application\UseCase\FindContactTemplates\{
    FindContactTemplatesPresenterInterface,
    FindContactTemplatesResponse
};
use Core\Infrastructure\Common\Presenter\PresenterFormatterInterface;

class FindContactTemplatesPresenter extends AbstractPresenter implements FindContactTemplatesPresenterInterface
{
    /**
     * @param RequestParametersInterface $requestParameters
     * @param PresenterFormatterInterface $presenterFormatter
     */
    public function __construct(
        private RequestParametersInterface $requestParameters,
        protected PresenterFormatterInterface $presenterFormatter,
    ) {
    }

    /**
     * @param FindContactTemplatesResponse $presentedData
     */
    public function present(mixed $presentedData): void
    {
        parent::present([
            'result' => $presentedData->contactTemplates,
            'meta' => $this->requestParameters->toArray(),
        ]);
    }
}
